summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRoland McGrath <roland@gnu.org>1994-10-25 07:38:51 +0000
committerRoland McGrath <roland@gnu.org>1994-10-25 07:38:51 +0000
commit1c96604021588d821aa8a8973f6d894724093626 (patch)
tree50b14c577236931924ff31e4c3f9c5a6465935e9
parent068f2da651ccac3c6faf9c6a17f0488d94bd076f (diff)
Comment fixes.
-rw-r--r--sysdeps/mach/hurd/fcntlbits.h41
1 files changed, 22 insertions, 19 deletions
diff --git a/sysdeps/mach/hurd/fcntlbits.h b/sysdeps/mach/hurd/fcntlbits.h
index cacd4d8c9c..ab2e647bdb 100644
--- a/sysdeps/mach/hurd/fcntlbits.h
+++ b/sysdeps/mach/hurd/fcntlbits.h
@@ -23,9 +23,10 @@ Cambridge, MA 02139, USA. */
/* File access modes. These are understood by io servers; they can be
- passed in `dir_pathtrans', and are returned by `io_get_openmodes'.
- Consequently they can be passed to `open', `hurd_path_lookup', and
- `path_lookup'; and are returned by `fcntl' with the F_GETFL command. */
+ passed in `dir_lookup', and are returned by `io_get_openmodes'.
+ Consequently they can be passed to `open', `hurd_file_name_lookup', and
+ `file_name_lookup'; and are returned by `fcntl' with the F_GETFL
+ command. */
/* In GNU, read and write are bits (unlike BSD). */
#ifdef __USE_GNU
@@ -42,8 +43,8 @@ Cambridge, MA 02139, USA. */
/* File name translation flags. These are understood by io servers;
- they can be passed in `dir_pathtrans', and consequently to `open',
- `hurd_path_lookup', and `path_lookup'. */
+ they can be passed in `dir_lookup', and consequently to `open',
+ `hurd_file_name_lookup', and `file_name_lookup'. */
#define O_CREAT 0x0010 /* Create file if it doesn't exist. */
#define O_EXCL 0x0020 /* Fail if file already exists. */
@@ -53,18 +54,18 @@ Cambridge, MA 02139, USA. */
#endif
-/* File status flags. These are understood by io servers; they can be
- passed in `dir_pathtrans' and set or fetched with `io_*_openmodes'.
- Consequently they can be passed to `open', `hurd_path_lookup',
- `path_lookup', and `fcntl' with the F_SETFL command; and are returned
- by `fcntl' with the F_GETFL command. */
+/* I/O operating modes. These are understood by io servers; they can be
+ passed in `dir_lookup' and set or fetched with `io_*_openmodes'.
+ Consequently they can be passed to `open', `hurd_file_name_lookup',
+ `file_name_lookup', and `fcntl' with the F_SETFL command; and are
+ returned by `fcntl' with the F_GETFL command. */
#define O_APPEND 0x0100 /* Writes always append to the file. */
#define O_ASYNC 0x0200 /* Send SIGIO to owner when data is ready. */
#define O_FSYNC 0x0400 /* Synchronous writes. */
#define O_SYNC O_FSYNC
#ifdef __USE_GNU
-#define O_NOATIME 0x0800 /* Don't set access time on read by owner. */
+#define O_NOATIME 0x0800 /* Don't set access time on read (owner). */
#endif
@@ -72,10 +73,12 @@ Cambridge, MA 02139, USA. */
translation flag and a file status flag. O_NDELAY is the deprecated BSD
name for the same flag, overloaded in the same way.
- When used in `dir_pathtrans' (and consequently `open', `hurd_path_lookup',
- or `path_lookup'), O_NONBLOCK says the open should fail with EAGAIN
- instead of blocking for any significant length of time (e.g., to wait for
- DTR on a serial line).
+ When used in `dir_lookup' (and consequently `open',
+ `hurd_file_name_lookup', or `file_name_lookup'), O_NONBLOCK says the
+ open should return immediately instead of blocking for any significant
+ length of time (e.g., to wait for carrier detect on a serial line). It
+ is also saved as a file status flag, and after open has the following
+ meaning.
When used in `io_*_openmodes' (and consequently `fcntl' with the F_SETFL
command), the O_NONBLOCK flag means to do nonblocking i/o: any i/o
@@ -84,7 +87,7 @@ Cambridge, MA 02139, USA. */
#define O_NONBLOCK 0x0008 /* Non-blocking open or non-blocking I/O. */
#ifdef __USE_BSD
-#define O_NDELAY O_NONBLOCK
+#define O_NDELAY O_NONBLOCK /* Deprecated. */
#endif
@@ -94,14 +97,14 @@ Cambridge, MA 02139, USA. */
#endif
-/* Open-time action flags. These are understood by `hurd_path_lookup'
- and consequently by `open' and `path_lookup'. They are not preserved
+/* Open-time action flags. These are understood by `hurd_file_name_lookup'
+ and consequently by `open' and `file_name_lookup'. They are not preserved
once the file has been opened. */
#define O_TRUNC 0x00010000 /* Truncate file to zero length. */
#ifdef __USE_MISC
#define O_SHLOCK 0x00020000 /* Open with shared file lock. */
-#define O_EXLOCK 0x00040000 /* Open with shared exclusive lock. */
+#define O_EXLOCK 0x00040000 /* Open with exclusive file lock. */
#endif